/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.exports.process;

import org.apache.log4j.Logger;
import org.jfree.data.xy.XYSeries;
import org.w3c.dom.Document;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.model.FacetTypes;
import org.dive4elements.river.artifacts.model.minfo.BedDiffYearResult;
import org.dive4elements.river.exports.StyledSeriesBuilder;
import org.dive4elements.river.exports.XYChartGenerator;
import org.dive4elements.river.jfree.StyledXYSeries;


public class BedDiffHeightYearProcessor implements Processor, FacetTypes {

    private final static Logger logger =
            Logger.getLogger(BedDiffHeightYearProcessor.class);

    @Override
    public void doOut(
            XYChartGenerator generator,
            ArtifactAndFacet aandf,
            Document theme,
            boolean visible,
            int index
    ) {
        CallContext context = generator.getCallContext();
        Object data = aandf.getData(context);
        if (data instanceof BedDiffYearResult) {
            doBedDifferenceYearOut(
               generator,
               (BedDiffYearResult) data,
               aandf, theme, visible, index);
            return;
        }
        logger.error("Can't process " + data.getClass().getName() + " objects");
    }

    @Override
    public boolean canHandle(String facetType) {
        return BED_DIFFERENCE_HEIGHT_YEAR.equals(facetType)
            || BED_DIFFERENCE_HEIGHT_YEAR_FILTERED.equals(facetType);
    }

    protected void doBedDifferenceYearOut(XYChartGenerator generator,
        BedDiffYearResult data,
        ArtifactAndFacet aandf,
        Document theme,
        boolean visible,
        int axidx) {

        XYSeries series = new StyledXYSeries(aandf.getFacetDescription(), theme);
        StyledSeriesBuilder.addPoints(series, data.getHeightPerYearData(), true);

        generator.addAxisSeries(series, axidx, visible);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
